searchData={"items":[{"type":"module","title":"Idiom","doc":"A new take on internationalisation in Elixir.","ref":"Idiom.html"},{"type":"module","title":"Basic usage - Idiom","doc":"```elixir\n# Set the locale\nIdiom.put_locale(\"en-US\")\n\nt(\"landing.welcome\")\n\n# With natural language key\nt(\"Hello Idiom!\")\n\n# With interpolation\nt(\"Good morning, {{name}}. We hope you are having a great day.\", %{name: \"Tim\"})\n\n# With plural and interpolation\n# `count` is a magic option that automatically is available as binding.\nt(\"You need to buy {{count}} carrots\", count: 1)\n\n# With namespace\nt(\"Create your account\", namespace: \"signup\")\nIdiom.put_namespace(\"signup\")\nt(\"Create your account\")\n\n# With explicit locale\nt(\"Create your account\", to: \"fr\")\n\n# With fallback key\nt([\"Create your account\", \"Register\"])\n\n# With fallback locale\nt(\"Create your account\", to: \"fr\", fallback: \"en\")\n```","ref":"Idiom.html#module-basic-usage"},{"type":"module","title":"Installation - Idiom","doc":"To start off, add `idiom` to the list of your dependencies:\n```elixir\ndef deps do\n  {:idiom, \"~> 0.1\"},\nend\n```\n\nAdditionally, in order to be able refresh translations in the background, add Idiom's `Supervisor` to your application:\n```elixir\ndef start(_type, _args) do\n  children = [\n    Idiom,\n  ]\n\n  # ...\nend\n```","ref":"Idiom.html#module-installation"},{"type":"module","title":"Configuration - Idiom","doc":"There are a few things around Idiom that you can configure on an application level. The following fence shows all of Idiom's settings and their defaults.\n\n```elixir\nconfig :idiom,\n  default_locale: \"en\",\n  default_fallback: \"en\",\n  default_namespace: \"default\",\n  data_dir: \"priv/idiom\",\n  backend: nil\n```\n\nIn order to configure your backend, please have a look at its module documentation.","ref":"Idiom.html#module-configuration"},{"type":"module","title":"Locales - Idiom","doc":"When calling `t/3`, Idiom looks at the following settings to determine which locale to translate the key to, in order of priority:\n\n1. The explicit `to` option. When you call `t(\"key\", to: \"fr\")`, Idiom will always use `fr` as a locale.\n2. The locale set in the current process. You can call `Idiom.put_locale/1` to set it.\nSince this is just a wrapper around the process dictionary, it needs to be set for each process you are using Idiom in.\n3. The `default_locale` setting. See the [Configuration](#module-configuration) section for more details on how to set it.\n\n#","ref":"Idiom.html#module-locales"},{"type":"module","title":"Resolution hierarchy - Idiom","doc":"> ##","ref":"Idiom.html#module-resolution-hierarchy"},{"type":"module","title":"A note on examples {: .info} - Idiom","doc":">\n> For ease of presentation, whenever an example in this module documentation includes a translation file for context, it will be merged from the multiple\n> files that `Idiom.Source.Local` actually expects. Instead of giving you the contents of all `en/default.json`, `en-US/default.json`, `en-GB/default.json`\n> and others, it will be represented here as one merged file, such as:\n\n> ```\n> { \n>   \"en\": {\"default\": { [Contents of what would usually be `en/default.json` ] }},\n>   \"en-US\": {\"default\": { [Contents of what would usually be `en-US/default.json` ] }},\n>   ...\n> }\n> ```\n\nLocale codes can consist of multiple parts. Taking `zh-Hant-HK` as an example, we have the language (`zh` - Chinese), the script (`Hant`, Tradtional) and the\nregion (`HK` - Hong Kong). For different regions, there might only be differences for some specific keys, whereas all other keys share a translation. In\norder to prevent needless repetition in your translation workflow, Idiom will always try to resolve translations in all of language, language and script, and\nlanguage, script and region variants, in order of specifity.\n\nTaking the following file as an example (see also [File format](#module-file-format)):\n```json\n{\n  \"en\": {\n    \"default\": {\n      \"Create your account\": \"Create your account\"\n    }\n  },\n  \"en-US\": {\n    \"default\": {\n      \"Take the elevator\": \"Take the elevator\"\n    }\n  },\n  \"en-GB\": {\n    \"default\": {\n      \"Take the elevator\": \"Take the lift\"\n    }\n  }\n}\n```\nThe `Create your account` message is the same for both American and British English, whereas the key `Take the elevator` has different wording for each.\nWith Idiom's resolution hierarchy, you can use both `en-US` and `en-GB` to refer to the `Create your account` key as well.\n\n```elixir\niex> t(\"Take the elevator\", to: \"en-US\")\n\"Take the elevator\"\n\niex> t(\"Take the elevator\", to: \"en-GB\")\n\"Take the lift\"\n\n# Will first try to resolve the key in the `en-US` locale, then, since it does not exist, try `en`.\niex> t(\"Create your account\", to: \"en-US\")\n\"Create your account\"\n\niex> t(\"Create your account\", to: \"en-GB\")\n\"Create your account\"\n```\n\n#","ref":"Idiom.html#module-a-note-on-examples-info"},{"type":"module","title":"Fallback keys - Idiom","doc":"For scenarios where multiple keys might apply, `t/3` allows specifying a list of keys as well.\n\n```elixir\nt([\"Create your account\", \"Register\"], to: \"en-US\")\n```\n\nThis snippet will first try to resolve the `Create your account` key, and fall back to resolving `Register` when it does not exist.\n\n#","ref":"Idiom.html#module-fallback-keys"},{"type":"module","title":"Fallback locales - Idiom","doc":"For when a key might not be available in the set locale, you can set a fallback locale.  \nA fallback can be either a string or a list of strings. If you set the fallback as a list, Idiom will return the translation of the first locale for which\nthe key is available.\n\nWhen you don't explicitly set a `fallback` for `t/3`, Idiom will try the `default_fallback` (see [Configuration](#module-configuration)).\nWhen a key is available in neither the target **or** any of the fallback language, the key will be returned as-is.\n\n\n```elixir\n# will return the translation for `en`\nt(\"Key that is only available in `en` and `fr`\", to: \"es\", fallback: \"en\")\n# will return the translation for `fr`\nt(\"Key that is only available in `en` and `fr`\", to: \"es\", fallback: [\"fr\", \"en\"])\n# will return the translation for `en`, which is set as `default_fallback`\nt(\"Key that is only available in `en` and `fr`\", to: \"es\")\n# will return \"Key that is not available in any locale\"\nt(\"Key that is not available in any locale\", to: \"es\")\n```\n\n#","ref":"Idiom.html#module-fallback-locales"},{"type":"module","title":"Using fallback keys and locales together - Idiom","doc":"When both fallback keys and locales are provided, Idiom will first try to resolve all keys in each locale before jumping to the next one.  \nFor example, the resolution order for `t([\"Create your account\", \"Register\"], to: \"es\", fallback: [\"fr\", \"de\"])` will be:\n\n1. `Create your account` in `es`\n2. `Register` in `es`\n3. `Create your account` in `fr`\n4. `Register` in `fr`\n5. `Create your account` in `de`\n6. `Register` in `de`","ref":"Idiom.html#module-using-fallback-keys-and-locales-together"},{"type":"module","title":"Namespaces - Idiom","doc":"Idiom allows grouping your keys into namespaces.\n\nWhen calling `t/3`, Idiom looks at the following settings to determine which namespace to resolve the key in, in order of priority:\n1. The `namespace` option, like `t(\"Create your account\", namespace: \"signup\")`\n2. The namespace set in the current process. You can call `Idiom.put_namespace/1` to set it.  \nSince this is just a wrapper around the process dictionary, it needs to be set for each process you are using Idiom in.\n3. The `default_namespace` setting. See the [Configuration](#module-configuration) section for more details on how to set it.","ref":"Idiom.html#module-namespaces"},{"type":"module","title":"Interpolation - Idiom","doc":"Idiom supports interpolation in messages.  \nInterpolation can be added by adding an interpolation key to the message, enclosing it in `{{}}`. Then, you can bind the key to any string by passing it as\nkey inside the second parameter of `t/3`.\n\nTaking the following file as an example (see also [File format](#module-file-format)):\n```json\n{\n  \"en\": {\n    \"default\": {\n      \"Welcome, {{name}}\": \"Welcome, {{name}}\",\n      \"It is currently {{temperature}} degrees in {{city}}\": \"It is currently {{temperature}} degrees in {{city}}\"\n    }\n  }\n}\n```\n\nThese messages can then be interpolated as such:\n\n```elixir\niex> t(\"Welcome, {{name}}\", %{name: \"Tim\"})\n\"Welcome, Tim\"\n\niex> t(\"It is currently {{temperature}} degrees in {{city}}\", %{temperature: \"31\", city: \"Hong Kong\"})\n\"It is currently 31 degrees in Hong Kong\"\n```","ref":"Idiom.html#module-interpolation"},{"type":"module","title":"Pluralisation - Idiom","doc":"Idiom supports the following key suffixes for pluralisation:\n\n- `zero`\n- `one`\n- `two`\n- `few`\n- `many`\n- `other`\n\nYour keys, for English, might then look like this:\n\n```json\n{\n  \"carrot_one\": \"{{count}} carrot\"\n  \"carrot_other\": \"{{count}} carrots\"\n}\n```\n\nYou can then pluralise your messages by passing `count` to `t/3`, such as:\n\n```elixir\niex> t(\"carrot\", count: 1)\n\"1 carrot\"\n\niex> t(\"carrot\", count: 2)\n\"2 carrots\"\n```\n\n> #### `{{count}}` and pluralisation {: .info}\n>\n> As you can see in the above example, we are not passing an extra `%{count: x}` binding. This is because the `count` option acts as a magic binding that is\n> automatically available for interpolation.","ref":"Idiom.html#module-pluralisation"},{"type":"module","title":"Backends - Idiom","doc":"Idiom is backend-agnostic and allows configuring different providers which are grouped under `Idiom.Backend`.\n\n#","ref":"Idiom.html#module-backends"},{"type":"module","title":"Phrase - Idiom","doc":"[Phrase Strings](https://phrase.com) is supported inside the `Idiom.Backend.Phrase` module.\n\n#","ref":"Idiom.html#module-phrase"},{"type":"module","title":"Lokalise - Idiom","doc":"[Lokalise](https://lokalise.com) is supported inside the `Idiom.Backend.Lokalise` module.","ref":"Idiom.html#module-lokalise"},{"type":"function","title":"Idiom.direction/1","doc":"","ref":"Idiom.html#direction/1"},{"type":"function","title":"Idiom.get_locale/0","doc":"Returns the locale that will be used by `t/3`.","ref":"Idiom.html#get_locale/0"},{"type":"function","title":"Examples - Idiom.get_locale/0","doc":"```elixir\niex> Idiom.get_locale()\n\"en-US\"\n```","ref":"Idiom.html#get_locale/0-examples"},{"type":"function","title":"Idiom.get_namespace/0","doc":"Returns the namespace that will be used by `t/3`.","ref":"Idiom.html#get_namespace/0"},{"type":"function","title":"Examples - Idiom.get_namespace/0","doc":"```elixir\niex> Idiom.get_namespace()\n\"default\"\n```","ref":"Idiom.html#get_namespace/0-examples"},{"type":"function","title":"Idiom.put_locale/1","doc":"Sets the locale for the current process.","ref":"Idiom.html#put_locale/1"},{"type":"function","title":"Examples - Idiom.put_locale/1","doc":"```elixir\niex> Idiom.put_locale(\"fr-FR\")\n\"fr-FR\"\n```","ref":"Idiom.html#put_locale/1-examples"},{"type":"function","title":"Idiom.put_namespace/1","doc":"Sets the namespace for the current process.","ref":"Idiom.html#put_namespace/1"},{"type":"function","title":"Examples - Idiom.put_namespace/1","doc":"```elixir\niex> Idiom.put_namespace(\"signup\")\n\"signup\"\n```","ref":"Idiom.html#put_namespace/1-examples"},{"type":"function","title":"Idiom.t/2","doc":"Alias of `t/3` for when you don't need any bindings.","ref":"Idiom.html#t/2"},{"type":"function","title":"Idiom.t/3","doc":"Translates a key into a target language.","ref":"Idiom.html#t/3"},{"type":"function","title":"Examples - Idiom.t/3","doc":"```elixir\niex> Idiom.t(\"hello\", to: \"es\")\n\"hola\"\n\n# With process-wide locale\niex> Idiom.put_locale(\"fr\")\niex> Idiom.t(\"hello\")\n\"bonjour\"\n\n# If neither `:to` option is provided nor `:lang` is set in the process, it will check the application configuration:\n# Given `config :idiom, default_lang: \"en\"` is set in the `config.exs` file:\niex> Idiom.t(\"hello\")\n\"hello\"\n\n# If a key does not exist in the target language, it will use the `:fallback` option:\niex> Idiom.t(\"hello\", to: \"de\", fallback: \"fr\")\n\"bonjour\"\n\n# If a key does not exist in the target language or the first fallback language:\niex> Idiom.t(\"hello\", to: \"de\", fallback: [\"pl\", \"fr\"])\n\"bonjour\"\n```","ref":"Idiom.html#t/3-examples"},{"type":"type","title":"Idiom.translate_opts/0","doc":"","ref":"Idiom.html#t:translate_opts/0"},{"type":"module","title":"Idiom.Backend","doc":"Idiom is backend-agnostic and allows configuring different providers which are grouped under `Idiom.Backend`.","ref":"Idiom.Backend.html"},{"type":"module","title":"Building your own - Idiom.Backend","doc":"Building an over-the-air backend is easy!  \n\n1. Build a module that can be started by a `Supervisor`.\n\n2. Write data to `Idiom.Cache`.\nIdiom's translations are stored inside an ETS table that is wrapped by `Idiom.Cache`. Your backend should update the cache by calling \n`Idiom.Cache.insert_keys/2`. See the documentation for that function on the expected data structure.","ref":"Idiom.Backend.html#module-building-your-own"},{"type":"module","title":"Idiom.Backend.Lokalise","doc":"Backend for [Lokalise](https://lokalise.com).\n\n> ##","ref":"Idiom.Backend.Lokalise.html"},{"type":"module","title":"Information {: .info} - Idiom.Backend.Lokalise","doc":">\n> The Lokalise backend is currently experimental.  \n> Since Lokalise does not officially support third-party SDKs, this backend is piggy-backing off of Lokalise's Android SDK format and then runs a \n> transformation on the received data to match Idiom's data model. At this point, there is no guarantee that all variations of that format are handled \n> correctly.  \n> If you find a bug, please [open an issue](https://github.com/cschmatzler/idiom/issues/new) with your Lokalise bundle data!","ref":"Idiom.Backend.Lokalise.html#module-information-info"},{"type":"module","title":"Usage - Idiom.Backend.Lokalise","doc":"In order to use the Lokalise backend, set it in your Idiom configuration:\n\n```elixir\nconfig :idiom,\n  backend: Idiom.Backend.Lokalise\n```","ref":"Idiom.Backend.Lokalise.html#module-usage"},{"type":"module","title":"Configuration - Idiom.Backend.Lokalise","doc":"The Lokalise backend currently supports the following configuration options:\n\n```elixir\nconfig :idiom, Idiom.Backend.Lokalise,\n  project_id: \"\", # required\n  api_token: \"\", # required\n  namespace: \"default\",\n  fetch_interval: 600_000,\n  otp_app: nil # optional, for Lokalise's bundle freeze support\n```","ref":"Idiom.Backend.Lokalise.html#module-configuration"},{"type":"module","title":"Creating a bundle - Idiom.Backend.Lokalise","doc":"Lokalise does not officially support any third-party SDKs or web application libraries. The Idiom backend works by fetching a bundle in the format of \nLokalise's official Android SDK and then transforming the data. This means that when you create a localisation bundle in the \"Download\" tab of your Lokalise\ndashboard, you need to select \"Android SDK\" under the \"File format\" setting. The `project_id` and `api_token` values can be found under the \n\"More -> Settings\" page where you can find your Project ID and can generate a \"Lokalise OTA Token\".","ref":"Idiom.Backend.Lokalise.html#module-creating-a-bundle"},{"type":"function","title":"Idiom.Backend.Lokalise.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Idiom.Backend.Lokalise.html#child_spec/1"},{"type":"module","title":"Idiom.Backend.Phrase","doc":"Backend for [Phrase](https://phrase.com).\n\n**Not yet complete. Use at your own risk. Things might break at any time.**","ref":"Idiom.Backend.Phrase.html"},{"type":"module","title":"Usage - Idiom.Backend.Phrase","doc":"In order to use the Phrase backend, set it in your Idiom configuration:\n\n```elixir\nconfig :idiom,\n  backend: Idiom.Backend.Phrase\n```","ref":"Idiom.Backend.Phrase.html#module-usage"},{"type":"module","title":"Configuration - Idiom.Backend.Phrase","doc":"The Phrase backend currently supports the following configuration options:\n\n```elixir\nconfig :idiom, Idiom.Backend.Phrase,\n  datacenter: \"eu\", # or \"us\"\n  distribution_id: \"\", # required\n  distribution_secret: \"\", # required\n  locales: [\"de-DE\", \"en-US\"], # required\n  namespace: \"default\",\n  fetch_interval: 600_000,\n  otp_app: nil # optional, for Phrase's appVersion support\n```\n\n#","ref":"Idiom.Backend.Phrase.html#module-configuration"},{"type":"module","title":"Creating a distribution - Idiom.Backend.Phrase","doc":"In order to create a Phrase Strings OTA distribution, head to the \"Over the air\" page in your Phrase dashboard and create a distribution using the\n`i18next (React Native)` platform. This will give you a Distribution ID as well as a secret for both development and production environments.","ref":"Idiom.Backend.Phrase.html#module-creating-a-distribution"},{"type":"function","title":"Idiom.Backend.Phrase.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Idiom.Backend.Phrase.html#child_spec/1"},{"type":"module","title":"Idiom.Backend.Utilities","doc":"Utilities for writing Idiom backends.","ref":"Idiom.Backend.Utilities.html"},{"type":"function","title":"Idiom.Backend.Utilities.maybe_add_app_version_to_opts/2","doc":"Adds an `app_version` field to the `GenServer` options if the `otp_app` configuration field was provided. \n\nThe application version is read from `mix.exs`.","ref":"Idiom.Backend.Utilities.html#maybe_add_app_version_to_opts/2"},{"type":"module","title":"Idiom.Cache","doc":"Cache for translations.  \n\nWraps an ETS table and offers functions to insert and fetch localisation data. table","ref":"Idiom.Cache.html"},{"type":"function","title":"Idiom.Cache.get_translation/4","doc":"Retrieves a translation from the cache.","ref":"Idiom.Cache.html#get_translation/4"},{"type":"function","title":"Examples - Idiom.Cache.get_translation/4","doc":"```elixir\niex> Cache.get_translation(\"de\", \"default\", \"butterfly\")\n\"Schmetterling\"\n```","ref":"Idiom.Cache.html#get_translation/4-examples"},{"type":"function","title":"Idiom.Cache.init/2","doc":"Starts a new cache.\n\nAllows adding initial state by passing it as first parameter.","ref":"Idiom.Cache.html#init/2"},{"type":"function","title":"Parameters - Idiom.Cache.init/2","doc":"- `initial_state` - State to initialise the cache with. See the documentation for `insert_keys/2` for the expected format.","ref":"Idiom.Cache.html#init/2-parameters"},{"type":"function","title":"Examples - Idiom.Cache.init/2","doc":"```elixir\niex> initial_state = %{\n...>  \"en\" => %{\"signup\" => %{\"Create your account\" => \"Create your account\"}}, \n...>  \"de\" => %{\"signup\" => %{\"Create your account\" => \"Erstelle deinen Account\"}}\n...>}\niex> Idiom.Cache.init(initial_state)\n:ok\n\niex> Idiom.Cache.init(%{}, :different_cache_name)\n:ok\n```","ref":"Idiom.Cache.html#init/2-examples"},{"type":"function","title":"Idiom.Cache.insert_keys/2","doc":"Adds a map of keys to the cache.","ref":"Idiom.Cache.html#insert_keys/2"},{"type":"function","title":"Parameters - Idiom.Cache.insert_keys/2","doc":"- `keys` - Map of keys to add to the cache.","ref":"Idiom.Cache.html#insert_keys/2-parameters"},{"type":"function","title":"Format of `keys` - Idiom.Cache.insert_keys/2","doc":"```elixir\n%{\n  \"en\" => %{\"signup\" => %{\"Create your account\" => \"Create your account\"}}, \n  \"de\" => %{\"signup\" => %{\"Create your account\" => \"Erstelle deinen Account\"}}}\n}\n```\n\nwhere the first level is the locale, the second the namespace, and the third a map of the keys contained in the previous two. The keys can be nested further,\nthe cache will automatically flatten them as such:\n\n```elixir\n%{\n  \"en\" => %{\n    \"signup\" => %{\n      \"multiple\" => %{\n        \"levels\" => %{\n          \"nesting\" => \"Hello!\"\n        }\n      }\n    }\n  }\n}\n```\n\nwill result in a key of `multiple.levels.nesting` inside the `signup` namespace with a message value of `Hello!`.","ref":"Idiom.Cache.html#insert_keys/2-format-of-keys"},{"type":"function","title":"Examples - Idiom.Cache.insert_keys/2","doc":"```elixir\niex> Idiom.Cache.insert_keys(%{\n...>  \"en\" => %{\"signup\" => %{\"Create your account\" => \"Create your account\"}}, \n...>  \"de\" => %{\"signup\" => %{\"Create your account\" => \"Erstelle deinen Account\"}}}\n...>)\n:ok\n```","ref":"Idiom.Cache.html#insert_keys/2-examples"},{"type":"module","title":"Idiom.Interpolation","doc":"Functionality for interpolating variables into a message.","ref":"Idiom.Interpolation.html"},{"type":"function","title":"Idiom.Interpolation.interpolate/2","doc":"Interpolates a message with a map of bindings.\n\nThe message can include variables wrapped in `{{}}`. For example, in the string `Hello, {{name}}!`, `{{name}}` is a variable. If a variable exists in the \nmessage , but not in the bindings, it is converted to a string in-place.\n\nThe binding can be any value that implements the `String.Chars` protocol.","ref":"Idiom.Interpolation.html#interpolate/2"},{"type":"function","title":"Examples - Idiom.Interpolation.interpolate/2","doc":"```elixir\niex> Idiom.Interpolation.interpolate(\"Hello, {{name}}!\", %{name: \"John\"})\n\"Hello, John!\"\n\niex> Idiom.Interpolation.interpolate(\"Hello, {{name}}! It is {{day_of_week}}.\", %{name: \"John\", day_of_week: \"Monday\"})\n\"Hello, John! It is Monday.\"\n\niex> Idiom.Interpolation.interpolate(\"Hello, {{name}}! It is {{day_of_week}}.\", %{name: \"John\"})\n\"Hello, John! It is day_of_week.\"\n```","ref":"Idiom.Interpolation.html#interpolate/2-examples"},{"type":"module","title":"Idiom.Local","doc":"Local data provider for Idiom.\n\nIdiom is backend-agnostic and can be used with many different providers. As a backup for when the selected source is unavailable, Idiom loads data from the\nlocal file system on startup.","ref":"Idiom.Local.html"},{"type":"module","title":"Directory structure - Idiom.Local","doc":"You can set the data directory changing the `:data_dir` setting `Idiom.Local` will use as such:\n\n```elixir\nconfig :idiom, data_dir: \"priv/idiom\"\n```\n\nInside that directory, the structure should be as follows:\n\n```\npriv/idiom\n└── en\n  ├── default.json\n  └── login.json\n```\n\nWhere `en` is the target locale and `default` and `login` are namespaces.","ref":"Idiom.Local.html#module-directory-structure"},{"type":"module","title":"File format - Idiom.Local","doc":"The `json` files expected by `Idiom.Local` are a subset of the [i18next format](https://www.i18next.com/misc/json-format). The following example shows all of\nits features that Idiom currently supports.\n\n```json\n{\n  \"key\": \"value\",\n  \"keyDeep\": {\n    \"inner\": \"value\"\n  },\n  \"keyInterpolate\": \"replace this {{value}}\",\n  \"keyPluralSimple_one\": \"the singular\",\n  \"keyPluralSimple_other\": \"the plural\",\n  \"keyPluralMultipleEgArabic_zero\": \"the plural form 0\",\n  \"keyPluralMultipleEgArabic_one\": \"the plural form 1\",\n  \"keyPluralMultipleEgArabic_two\": \"the plural form 2\",\n  \"keyPluralMultipleEgArabic_few\": \"the plural form 3\",\n  \"keyPluralMultipleEgArabic_many\": \"the plural form 4\",\n  \"keyPluralMultipleEgArabic_other\": \"the plural form 5\",\n}\n```","ref":"Idiom.Local.html#module-file-format"},{"type":"function","title":"Idiom.Local.read/1","doc":"Parses all local data.","ref":"Idiom.Local.html#read/1"},{"type":"module","title":"Idiom.Locales","doc":"Functionality for interacting with locales.\n\nLocale identifiers consist of a language code, an optional script code, and an optional region code, separated by a hyphen (-) or underscore (_).","ref":"Idiom.Locales.html"},{"type":"function","title":"Idiom.Locales.direction/1","doc":"Returns the writing direction of the script belonging to the locale.","ref":"Idiom.Locales.html#direction/1"},{"type":"function","title":"Examples - Idiom.Locales.direction/1","doc":"```elixir\niex> Idiom.Locales.direction(\"en-US\")\n:ltr\n\niex> Idiom.Locales.direction(\"ar\")\n:rtl\n```","ref":"Idiom.Locales.html#direction/1-examples"},{"type":"function","title":"Idiom.Locales.format_locale/1","doc":"Formats a locale string.\n\nIdiom internally supports separating different parts of the locale code by either hyphen or underscore, which is then normalised by this function.","ref":"Idiom.Locales.html#format_locale/1"},{"type":"function","title":"Examples - Idiom.Locales.format_locale/1","doc":"```elixir\niex> Idiom.Locales.format_locale(\"de_de\")\n\"de-DE\"\n\niex> Idiom.Locales.format_locale(\"zh-hant-hk\")\n\"zh-Hant-HK\"\n```","ref":"Idiom.Locales.html#format_locale/1-examples"},{"type":"function","title":"Idiom.Locales.get_hierarchy/2","doc":"Constructs a hierarchical list of locale identifiers from the given locale.\n\nThe `fallback` option allows you to specify a fallback locale or a list of fallback locales that will be added to the end of the hierarchy if it's not \nalready included. By default, no fallback language is added.","ref":"Idiom.Locales.html#get_hierarchy/2"},{"type":"function","title":"Examples - Idiom.Locales.get_hierarchy/2","doc":"```elixir\niex> Idiom.Locales.get_hierarchy(\"en-Latn-US\")\n[\"en-Latn-US\", \"en-Latn\", \"en\"]\n\niex> Idiom.Locales.get_hierarchy(\"de-DE\", fallback: \"en\")\n[\"de-DE\", \"de\", \"en\"]\n\niex> Idiom.Locales.get_hierarchy(\"de-DE\", fallback: [\"en-US\", \"fr\"])\n[\"de-DE\", \"de\", \"en-US\", \"fr\"]\n```","ref":"Idiom.Locales.html#get_hierarchy/2-examples"},{"type":"function","title":"Idiom.Locales.get_language/1","doc":"Extracts the language code from the given locale identifier.","ref":"Idiom.Locales.html#get_language/1"},{"type":"function","title":"Examples - Idiom.Locales.get_language/1","doc":"```elixir\niex> Idiom.Locales.get_language(\"en-Latn-US\")\n\"en\"\n\niex> Idiom.Locales.get_language(\"de-DE\")\n\"de\"\n```","ref":"Idiom.Locales.html#get_language/1-examples"},{"type":"function","title":"Idiom.Locales.get_language_and_script/1","doc":"Extracts the language and script codes from the given locale identifier.\n\nReturns `nil` if the given locale does not have a script code.","ref":"Idiom.Locales.html#get_language_and_script/1"},{"type":"function","title":"Examples - Idiom.Locales.get_language_and_script/1","doc":"```elixir\niex> Idiom.Locales.get_language_and_script(\"en-Latn-US\")\n\"en-Latn\"\n\niex> Idiom.Locales.get_language_and_script(\"de-DE\")\nnil\n\niex> Idiom.Locales.get_language_and_script(\"de-de-de\")\nnil\n```","ref":"Idiom.Locales.html#get_language_and_script/1-examples"},{"type":"type","title":"Idiom.Locales.get_hierarchy_opts/0","doc":"","ref":"Idiom.Locales.html#t:get_hierarchy_opts/0"},{"type":"module","title":"Idiom.Plural","doc":"Functionality for handling plurals and plural suffixes.\n\nIdiom handles plurals by adding suffixes to keys. These suffixes are as defined by the Unicode CLDR plural rules:\n- `zero`\n- `one`\n- `two`\n- `few`\n- `many`\n- `other`","ref":"Idiom.Plural.html"},{"type":"function","title":"Idiom.Plural.get_suffix/3","doc":"Returns the appropriate plural suffix based on a given locale, count and plural type.\n\nThe function will determine the correct plural form to use based on the `count` \nparameter. It supports different types of count values, including binary, float, \ninteger and Decimal types.\n\nIt also allows selecting whether you want to receive the suffix for cardinal or\nordinal plurals by passing `:cardinal` or `:ordinal` as the `type` option, where\ncardinal is the default plural type.\n\nWhen the count is `nil`, the function will default to `other`.","ref":"Idiom.Plural.html#get_suffix/3"},{"type":"function","title":"Examples - Idiom.Plural.get_suffix/3","doc":"```elixir\niex> Idiom.Plural.get_suffix(\"en\", 1)\n\"one\"\n\niex> Idiom.Plural.get_suffix(\"en\", 2, type: :cardinal)\n\"other\"\n\niex> Idiom.Plural.get_suffix(\"en\", 2, type: :ordinal)\n\"two\"\n\niex> Idiom.Plural.get_suffix(\"ar\", 0)\n\"zero\"\n\niex> Idiom.Plural.get_suffix(\"ar\", \"5\")\n\"few\"\n\niex> Idiom.Plural.get_suffix(\"ar\", Decimal.new(5))\n\"few\"\n```","ref":"Idiom.Plural.html#get_suffix/3-examples"},{"type":"function","title":"Idiom.Plural.get_suffixes/2","doc":"Returns a locale's plural suffixes for the specific plural type.","ref":"Idiom.Plural.html#get_suffixes/2"},{"type":"function","title":"Examples - Idiom.Plural.get_suffixes/2","doc":"```elixir\niex> Idiom.Plural.get_suffixes(\"en-US\", :cardinal)\n[\"one\", \"other\"]\n\niex> Idiom.Plural.get_suffixes(\"en-US\", :ordinal)\n[\"one\", \"two\", \"few\", \"other\"]\n```","ref":"Idiom.Plural.html#get_suffixes/2-examples"},{"type":"type","title":"Idiom.Plural.count/0","doc":"","ref":"Idiom.Plural.html#t:count/0"},{"type":"module","title":"Idiom.PluralAST","doc":"Preprocessor for language-specific pluralization rules.\n\nIdiom uses Unicode CLDR plural rules, which they provide for download as a JSON file. This is stored in our `priv` directory.\nThe `Plural` and `PluralAST` modules use these definitions to generate Elixir ASTs representing a `cond` statement for each language, which are then\nused at compile-time to generate functions.\n\nThis module builds on a lexer and parser inside the `src/` directory to generate the ASTs.","ref":"Idiom.PluralAST.html"},{"type":"task","title":"mix idiom.extract","doc":"Extracts keys into a template directory that can be used for localisation.","ref":"Mix.Tasks.Idiom.Extract.html"},{"type":"task","title":"Setup - mix idiom.extract","doc":"In order to be able to extract keys, this task will hook into the compilation step. Since only macro calls are expanded at compile time, calls to `Idiom.t/3`\ndirectly will not work. To work around this, Idiom includes a `__using__/1` macro that exposes the same API while at the same time making calls available\nat compile time.\n\nIf you are just getting started with Idiom, setting this up is easy: create a new module, for example `Project.Localisation` and `use Idiom` in it:\n\n```elixir\ndefmodule Project.Localisation do\n  use Idiom\nend\n```\n\nThen, you can just `import Project.Localisation` and use `t/3` as in the documentation for Idiom.\n\nIf you are currently directly calling `t/3` without `use`-ing Idiom, create the same module and in addition replace your `import Idiom` calls with\n`import Project.Localisation`. Afterwards, your keys will be available to `mix idiom.extract`.","ref":"Mix.Tasks.Idiom.Extract.html#module-setup"},{"type":"task","title":"Arguments - mix idiom.extract","doc":"- `--base-locale` (required): Sets the base locale of the template.  \n- `--data-dir`: Directory to extract template to. Will default to the `data_dir` configuration setting, or `priv/idiom` if neither command-line option nor \n  setting exist.  \n- `--default-namespace`: Default namespace. When the `idiom.extract` tasks finds a call to `Idiom.t/3` that passes `namespace` explicitly, it will be used \n  for extractions. For situations where the namespace is not set explicitly but through `Idiom.put_namespace/1`, you can set the namespace to extract to \n  using this option.  \n- `--files`: Filters files to extract. When using the `default-namespace`, you will probably only want to extract keys from specific modules which can be\n  selected using this option. Accepts everything that `Path.wildcard/1` accepts.","ref":"Mix.Tasks.Idiom.Extract.html#module-arguments"},{"type":"task","title":"Examples - mix idiom.extract","doc":"```bash\n# Extract all keys with English as base\nmix idiom.extract --base-locale en\n\n# Extract all keys in the \"signup\" folder and add them to the \"singup\" namespace\nmix idiom.extract --base-locale en --default-namespace signup --files lib/project_web/live/signup/**\n```","ref":"Mix.Tasks.Idiom.Extract.html#module-examples"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"0.6.8 (2024-05-01) - Changelog","doc":"#","ref":"changelog.html#0-6-8-2024-05-01"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fixes crash when not setting `otp_app` in configuration.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"0.6.7 (2024-04-23) - Changelog","doc":"#","ref":"changelog.html#0-6-7-2024-04-23"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fixes crash when passing `nil` to `t/3`.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"0.6.6 (2024-04-08) - Changelog","doc":"#","ref":"changelog.html#0-6-6-2024-04-08"},{"type":"extras","title":"Features - Changelog","doc":"* Updates plural definitions: now supports the `blo` language code for plurals\n\n#","ref":"changelog.html#features"},{"type":"extras","title":"Maintenance - Changelog","doc":"* Updates dependencies\n* Removes deprecation warnings for Elixir 1.16","ref":"changelog.html#maintenance"},{"type":"extras","title":"0.6.5 (2023-10-03) - Changelog","doc":"#","ref":"changelog.html#0-6-5-2023-10-03"},{"type":"extras","title":"Features - Changelog","doc":"* Allow interpolation binding keys to be strings (ab5d78c)\n```elixir\nt(\"It is {{month}} {{day}}, {{year}}\", %{\"month\" => \"February\", \"day\" => 3, year: 2023})\n```\n\n#","ref":"changelog.html#features"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fixes some functions being called multiple times (2260079)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Integrating with Phoenix","doc":"You can integrate Idiom with your Phoenix project quite simply.","ref":"integrating-with-phoenix.html"},{"type":"extras","title":"Importing Idiom - Integrating with Phoenix","doc":"Begin by importing Idiom into your `MyAppWeb` module which brings in a couple of helper functions used commonly in your views:\n\n```elixir\ndefmodule MyAppWeb do\n  def html_helpers do\n    quote do\n      import Phoenix.HTML\n      import Idiom\n      # ... Other imports\n    end\n  end\nend\n```","ref":"integrating-with-phoenix.html#importing-idiom"},{"type":"extras","title":"User-preferred language - Integrating with Phoenix","doc":"If your user schema includes a `preferred_language` field (storing a locale string), the `put_locale/1` function can be used during mount to set the active \nlanguage per user's preferred language:\n\n```elixir\ndefp mount_current_user(socket, session) do\n  Phoenix.Component.assign_new(socket, :current_user, fn ->\n    with user_token when not is_nil(user_token) <- session[\"user_token\"],\n         %Accounts.User{} = user <- Accounts.get_user_by_session_token(user_token) do\n      Idiom.put_locale(user.preferred_language)\n      user\n    end\n  end)\nend\n```","ref":"integrating-with-phoenix.html#user-preferred-language"},{"type":"extras","title":"Translations in templates - Integrating with Phoenix","doc":"You can use `t/2` and `t/3` functions directly in your Phoenix templates:\n\n```elixir\n~H\"\"\"\n<%= t(\"Welcome!\") %>\n\n<!-- With bindings -->\n<%= t(\"Welcome, {{name}}!\", %{name: @current_user.name}) %>\n\"\"\"\n```","ref":"integrating-with-phoenix.html#translations-in-templates"},{"type":"extras","title":"Using namespaces for pages - Integrating with Phoenix","doc":"You can organise your translations using namespaces and set a namespace per page:\n\n```elixir\ndef mount(_params, _session, socket) do\n    Idiom.put_namespace(\"signup\")\n\n    {:ok, reply}\nend\n\ndef render(assigns) do\n    ~H\"\"\"\n    <%= t(\"Create your account\") %>\n    \"\"\"\nend\n```\n\nHere, the actual translation key becomes `\"signup.Create your account\"`.","ref":"integrating-with-phoenix.html#using-namespaces-for-pages"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}